|Docs| |PyPI| |Master| |MasterTest| |CodeCov|

ktplots-*py*
------------

|logo|

Welcome! This is a super light-weight python library for plotting 
`CellphoneDB <https://www.github.com/ventolab/CellphoneDB/>`__ results. Ported from 
`ktplots <https://www.github.com/zktuong/ktplots/>`__ R package. For more options, 
please check out the original R 
`package <https://www.github.com/zktuong/ktplots/>`__.

The documentation is
`here <https://ktplotspy.readthedocs.io/>`__.

Installation
------------

.. code:: bash

    pip install ktplotspy


Support
-------

Support is provided on a voluntary basis, as time permits.

If there are any ideas, comments, suggestions, thing you would like to
know more etc., please feel free to email me at z.tuong@uq.edu.au or
post in the issue tracker and I will get back to you.

Citation
--------

If you find this useful, please consider citing the github repositories. Also leave a star at the 
`ktplotspy <https://www.github.com/zktuong/ktplotspy/>`__ and the original
`ktplots <https://www.github.com/zktuong/ktplots/>`__ repositories!

.. |Docs| image:: https://readthedocs.org/projects/ktplotspy/badge/?version=latest
   :target: https://ktplotspy.readthedocs.io/en/latest/?badge=latest
.. |PyPI| image:: https://img.shields.io/pypi/v/ktplotspy?logo=PyPI
   :target: https://pypi.org/project/ktplotspy/
.. |Master| image:: https://byob.yarr.is/zktuong/ktplotspy/version
   :target: https://github.com/zktuong/ktplotspy/tree/master
.. |MasterTest| image:: https://github.com/zktuong/ktplotspy/workflows/tests/badge.svg?branch=master
   :target: https://github.com/zktuong/ktplotspy/actions/workflows/tests.yml
.. |CodeCov| image:: https://codecov.io/gh/zktuong/ktplotspy/branch/master/graph/badge.svg?token=661BMU1FBO
   :target: https://codecov.io/gh/zktuong/ktplotspy
.. |logo| image:: docs/notebooks/logo.png
